controller property
Optional external controller. Expose this to allow the parent widget to trigger refreshes from outside the sliver.
Implementation
final MoInfiniteScrollController<T>? controller;
Optional external controller. Expose this to allow the parent widget to trigger refreshes from outside the sliver.
final MoInfiniteScrollController<T>? controller;