emptyPlaceholder property
Widget shown when the list is empty after a successful fetch. Defaults to DefaultEmptyPlaceholder.
Implementation
final Widget? emptyPlaceholder;
Widget shown when the list is empty after a successful fetch. Defaults to DefaultEmptyPlaceholder.
final Widget? emptyPlaceholder;