loadingMoreIndicator property
Optional widget displayed at the end of the list when more items are being fetched (pagination loading indicator). If null, no indicator is shown.
Implementation
final Widget? loadingMoreIndicator;
Optional widget displayed at the end of the list when more items are being fetched (pagination loading indicator). If null, no indicator is shown.
final Widget? loadingMoreIndicator;