MoInfiniteScrollState enum
Represents the three distinct UI states that both infinite scroll widgets can be in at any given moment.
Used to decide which placeholder widget (if any) should be shown.
Values
- loading → const MoInfiniteScrollState
-
A fetch is in progress and no items have been loaded yet (first load).
- empty → const MoInfiniteScrollState
-
At least one fetch completed successfully but returned zero items total.
- error → const MoInfiniteScrollState
-
The last fetch threw an error.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MoInfiniteScrollState> - A constant List of the values in this enum, in order of their declaration.